@@ -144,6 +144,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk
@@ -165,17 +167,17 @@ class CheapVpc(
         default_instance_tenancy: typing.Optional[aws_cdk.aws_ec2.DefaultInstanceTenancy] = None,
         enable_dns_hostnames: typing.Optional[builtins.bool] = None,
         enable_dns_support: typing.Optional[builtins.bool] = None,
-        flow_logs: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ec2.FlowLogOptions]] = None,
-        gateway_endpoints: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ec2.GatewayVpcEndpointOptions]] = None,
+        flow_logs: typing.Optional[typing.Mapping[builtins.str, typing.Union[aws_cdk.aws_ec2.FlowLogOptions, typing.Dict[str, typing.Any]]]] = None,
+        gateway_endpoints: typing.Optional[typing.Mapping[builtins.str, typing.Union[aws_cdk.aws_ec2.GatewayVpcEndpointOptions, typing.Dict[str, typing.Any]]]] = None,
         max_azs: typing.Optional[jsii.Number] = None,
         nat_gateway_provider: typing.Optional[aws_cdk.aws_ec2.NatProvider] = None,
         nat_gateways: typing.Optional[jsii.Number] = None,
-        nat_gateway_subnets: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
-        subnet_configuration: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.SubnetConfiguration]] = None,
-        vpn_connections: typing.Optional[typing.Mapping[builtins.str, aws_cdk.aws_ec2.VpnConnectionOptions]] = None,
+        nat_gateway_subnets: typing.Optional[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]] = None,
+        subnet_configuration: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.SubnetConfiguration, typing.Dict[str, typing.Any]]]] = None,
+        vpn_connections: typing.Optional[typing.Mapping[builtins.str, typing.Union[aws_cdk.aws_ec2.VpnConnectionOptions, typing.Dict[str, typing.Any]]]] = None,
         vpn_gateway: typing.Optional[builtins.bool] = None,
         vpn_gateway_asn: typing.Optional[jsii.Number] = None,
-        vpn_route_propagation: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.SubnetSelection]] = None,
+        vpn_route_propagation: typing.Optional[typing.Sequence[typing.Union[aws_cdk.aws_ec2.SubnetSelection, typing.Dict[str, typing.Any]]]] = None,
     ) -> None:
         '''
         :param scope: -
@@ -196,6 +198,10 @@ class CheapVpc(
         :param vpn_gateway_asn: The private Autonomous System Number (ASN) for the VPN gateway. Default: - Amazon default ASN.
         :param vpn_route_propagation: Where to propagate VPN routes. Default: - On the route tables associated with private subnets. If no private subnets exists, isolated subnets are used. If no isolated subnets exists, public subnets are used.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CheapVpc.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = aws_cdk.aws_ec2.VpcProps(
             cidr=cidr,
             default_instance_tenancy=default_instance_tenancy,
@@ -228,7 +234,7 @@ class CreateTags(
         id: builtins.str,
         *,
         resource_ids: typing.Sequence[builtins.str],
-        tags: typing.Sequence["Tag"],
+        tags: typing.Sequence[typing.Union["Tag", typing.Dict[str, typing.Any]]],
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
     ) -> None:
         '''
@@ -238,6 +244,10 @@ class CreateTags(
         :param tags: (experimental) The tags. The value parameter is required, but if you don't want the tag to have a value, specify the parameter with no value, and we set the value to an empty string.
         :param removal_policy: 
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CreateTags.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CreateTagsProps(
             resource_ids=resource_ids, tags=tags, removal_policy=removal_policy
         )
@@ -259,7 +269,7 @@ class CreateTagsProps:
         self,
         *,
         resource_ids: typing.Sequence[builtins.str],
-        tags: typing.Sequence["Tag"],
+        tags: typing.Sequence[typing.Union["Tag", typing.Dict[str, typing.Any]]],
         removal_policy: typing.Optional[aws_cdk.RemovalPolicy] = None,
     ) -> None:
         '''(experimental) Adds or overwrites only the specified tags for the specified Amazon EC2 resource or resources.
@@ -273,6 +283,11 @@ class CreateTagsProps:
         :see: https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_CreateTags.html
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(CreateTagsProps.__init__)
+            check_type(argname="argument resource_ids", value=resource_ids, expected_type=type_hints["resource_ids"])
+            check_type(argname="argument tags", value=tags, expected_type=type_hints["tags"])
+            check_type(argname="argument removal_policy", value=removal_policy, expected_type=type_hints["removal_policy"])
         self._values: typing.Dict[str, typing.Any] = {
             "resource_ids": resource_ids,
             "tags": tags,
@@ -336,6 +351,10 @@ class Tag:
         :param key: The key of the tag. Constraints: Tag keys are case-sensitive and accept a maximum of 127 Unicode characters. May not begin with aws:.
         :param value: The value of the tag. Constraints: Tag values are case-sensitive and accept a maximum of 256 Unicode characters.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Tag.__init__)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         self._values: typing.Dict[str, typing.Any] = {
             "key": key,
             "value": value,
